@@ -2,9 +2,9 @@ package AI::XGBoost;
 use strict;
 use warnings;
 
-our $VERSION = '0.002';    # VERSION
+our $VERSION = '0.003';    # VERSION
 
-# ABSTRACT: Perl wrapper for XGBoost library https://github.com/dmlc/xgboost
+# ABSTRACT: Perl wrapper for XGBoost library L<https://github.com/dmlc/xgboost>
 
 1;
 
@@ -16,11 +16,11 @@ __END__
 
 =head1 NAME
 
-AI::XGBoost - Perl wrapper for XGBoost library https://github.com/dmlc/xgboost
+AI::XGBoost - Perl wrapper for XGBoost library L<https://github.com/dmlc/xgboost>
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -60,10 +60,14 @@ version 0.002
 
 =head1 DESCRIPTION
 
-Perl wrapper for XGBoost library. This version only wraps the C API.
+Perl wrapper for XGBoost library. This version only wraps part of the C API.
 
 The documentation can be found in L<AI::XGBoost::CAPI>
 
+Currently this module need the xgboost binary available in your system. 
+I'm going to make an Alien module for xgboost but meanwhile you need to
+compile yourself xgboost: L<https://github.com/dmlc/xgboost>
+
 =head1 ROADMAP
 
 The goal is to make a full wrapper for XGBoost.
