@@ -4,7 +4,7 @@ use warnings;
 
 use parent 'NativeCall';
 
-our $VERSION = '0.002';    # VERSION
+our $VERSION = '0.003';    # VERSION
 
 # ABSTRACT: Perl wrapper for XGBoost C API https://github.com/dmlc/xgboost
 
@@ -12,6 +12,12 @@ sub XGBGetLastError : Args() : Native(xgboost) : Returns(string) { }
 
 sub XGDMatrixCreateFromFile : Args(string, int, opaque*) : Native(xgboost) : Returns(int) { }
 
+sub XGDMatrixCreateFromCSREx : Args(size_t*, uint*, float*, size_t, size_t, size_t, opaque*) : Native(xgboost) :
+  Returns(int) { }
+
+sub XGDMatrixCreateFromCSCEx : Args(size_t*, uint*, float*, size_t, size_t, size_t, opaque*) : Native(xgboost) :
+  Returns(int) { }
+
 sub XGDMatrixCreateFromMat : Args(float *, uint64, uint64, float, opaque*) : Native(xgboost) : Returns(int) { }
 
 sub XGDMatrixSliceDMatrix : Args(opaque, int *, uint64, opaque*) : Native(xgboost) : Returns(int) { }
@@ -38,10 +44,18 @@ sub XGBoosterCreate : Args(opaque[], uint64, opaque*) : Native(xgboost) : Return
 
 sub XGBoosterFree : Args(opaque) : Native(xgboost) : Returns(int) { }
 
+sub XGBoosterSetParam : Args(opaque, string, string) : Native(xgboost) : Returns(int) { }
+
+sub XGBoosterBoostOneIter : Args(opaque, opaque, float*, float*, uint64) : Native(xgboost) : Returns(int) { }
+
 sub XGBoosterUpdateOneIter : Args(opaque, int, opaque) : Native(xgboost) : Returns(int) { }
 
 sub XGBoosterPredict : Args(opaque, opaque, int, uint, uint64*, opaque*) : Native(xgboost) : Returns(int) { }
 
+sub XGBoosterLoadModel : Args(opaque, string) : Native(xgboost) : Returns(int) { }
+
+sub XGBoosterSaveModel : Args(opaque, string) : Native(xgboost) : Returns(int) { }
+
 1;
 
 __END__
@@ -56,7 +70,7 @@ AI::XGBoost::CAPI - Perl wrapper for XGBoost C API https://github.com/dmlc/xgboo
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -136,6 +150,78 @@ a loaded data matrix
 
 =back
 
+=head2 XGDMatrixCreateFromCSREx
+
+Create a matrix content from CSR fromat
+
+Parameters:
+
+=over 4
+
+=item indptr
+
+pointer to row headers
+
+=item indices
+
+findex
+
+=item data
+
+fvalue
+
+=item nindptr
+
+number of rows in the matrix + 1
+
+=item nelem
+
+number of nonzero elements in the matrix
+
+=item num_col
+
+number of columns; when it's set to 0, then guess from data
+
+=item out
+
+created dmatrix
+
+=back
+
+=head2 XGDMatrixCreateFromCSCEx
+
+Create a matrix content from CSC format
+
+Parameters:
+
+=over 4
+
+=item col_ptr
+
+pointer to col headers
+
+=item indices
+
+findex
+
+=item data
+
+fvalue
+
+=item nindptr
+
+number of rows in the matrix + 1
+
+=item nelem
+
+number of nonzero elements in the matrix
+
+=item num_row
+
+number of rows; when it's set to 0, then guess from data
+
+=back
+
 =head2 XGDMatrixCreateFromMat
 
 Create matrix content from dense matrix
@@ -416,6 +502,59 @@ handle to be freed
 
 =back
 
+=head2 XGBoosterSetParam
+
+Update the model in one round using dtrain
+
+Parameters:
+
+=over 4
+
+=item handle
+
+handle
+
+=item name
+
+parameter name
+
+=item value
+
+value of parameter
+
+=back
+
+=head2 XGBoosterBoostOneIter
+
+Update the modelo, by directly specify grandient and second order gradient,
+this can be used to replace UpdateOneIter, to support customized loss function
+
+Parameters:
+
+=over 4
+
+=item handle
+
+handle
+
+=item dtrain
+
+training data
+
+=item grad
+
+gradient statistics
+
+=item hess
+
+second order gradinet statistics
+
+=item len
+
+length of grad/hess array
+
+=back
+
 =head2 XGBoosterUpdateOneIter
 
 Update the model in one round using dtrain
@@ -493,6 +632,42 @@ used to set a pointer to array
 
 =back
 
+=head2 XGBoosterLoadModel
+
+Load model form existing file
+
+Parameters:
+
+=over 4
+
+=item handle
+
+handle
+
+=item fname
+
+file name
+
+=back
+
+=head2 XGBoosterSaveModel
+
+Save model into existing file
+
+Parameters:
+
+=over 4
+
+=item handle
+
+handle
+
+=item fname
+
+file name
+
+=back
+
 =head1 AUTHOR
 
 Pablo Rodríguez González <pablo.rodriguez.gonzalez@gmail.com>
